==> ejc-car-api-3.0.0-20231010.025321-7-sources.jar: com/ejianc/business/car/vo/DispatchVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 车辆调度
 * 
 * @author generator
 * 
 */
public class DispatchVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long carId; // 车牌号id
    private String carName; // 车辆名称 设备名称
    private String carCode; // 车牌号
    private Long carTypeId; // 车辆类型
    private String carTypeName; // 车辆类型
    private Long carAreaId; // 车辆所在区域
    private String carAreaName; // 车辆所在区域
    private Integer dispatchType; // 调度类型 0:临时调度；1:长期调度
    private Date beginDate; // 开始日期
    private Date endDate; // 归还日期
    private Long carProjectId; // 所属项目 车辆所在项目
    private String carProjectName; // 所属项目 车辆所在项目
    private Long orgId; // 所属组织
    private String orgName; // 所属组织
    private Long parentOrgId; // 所属上级组织
    private String parentOrgName; // 所属上级组织
    private Long carOrgId; // 所属公司 车辆所属公司
    private String carOrgName; // 所属公司 车辆所属公司
    private Long dispatchProjectId; // 调入项目
    private String dispatchProjectName; // 调入项目
    private Long dispatchOrgId; // 调入公司
    private String dispatchOrgName; // 调入公司
    private String insuranceInformation; // 保险信息
    private Long manageId; // 主管
    private String manageName; // 主管
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private Long managePhone; // 主管手机号
    private Long applyManageId; // 申请主管
    private String applyManageName; // 申请主管
    private Long useId; // 使用人
    private String useName; // 使用人
    private String usePhone; // 使用人手机号
    private Long applyId; // 申请人
    private String applyName; // 申请人
    private Long applyDeptId; // 申请部门
    private String applyDeptName; // 申请部门
    private String memo; // 调车事由
    private String billCode; // 单据编号

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getCarId() {
        return carId;
    }

    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getCarName() {
        return carName;
    }

    public void setCarName(String carName) {
        this.carName = carName;
    }
    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }
    public Long getCarTypeId() {
        return carTypeId;
    }

    public void setCarTypeId(Long carTypeId) {
        this.carTypeId = carTypeId;
    }
    public String getCarTypeName() {
        return carTypeName;
    }

    public void setCarTypeName(String carTypeName) {
        this.carTypeName = carTypeName;
    }
    public Long getCarAreaId() {
        return carAreaId;
    }

    public void setCarAreaId(Long carAreaId) {
        this.carAreaId = carAreaId;
    }
    public String getCarAreaName() {
        return carAreaName;
    }

    public void setCarAreaName(String carAreaName) {
        this.carAreaName = carAreaName;
    }
    public Integer getDispatchType() {
        return dispatchType;
    }

    public void setDispatchType(Integer dispatchType) {
        this.dispatchType = dispatchType;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Long getCarProjectId() {
        return carProjectId;
    }

    public void setCarProjectId(Long carProjectId) {
        this.carProjectId = carProjectId;
    }
    public String getCarProjectName() {
        return carProjectName;
    }

    public void setCarProjectName(String carProjectName) {
        this.carProjectName = carProjectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getCarOrgId() {
        return carOrgId;
    }

    public void setCarOrgId(Long carOrgId) {
        this.carOrgId = carOrgId;
    }
    public String getCarOrgName() {
        return carOrgName;
    }

    public void setCarOrgName(String carOrgName) {
        this.carOrgName = carOrgName;
    }
    public Long getDispatchProjectId() {
        return dispatchProjectId;
    }

    public void setDispatchProjectId(Long dispatchProjectId) {
        this.dispatchProjectId = dispatchProjectId;
    }
    public String getDispatchProjectName() {
        return dispatchProjectName;
    }

    public void setDispatchProjectName(String dispatchProjectName) {
        this.dispatchProjectName = dispatchProjectName;
    }
    public Long getDispatchOrgId() {
        return dispatchOrgId;
    }

    public void setDispatchOrgId(Long dispatchOrgId) {
        this.dispatchOrgId = dispatchOrgId;
    }
    public String getDispatchOrgName() {
        return dispatchOrgName;
    }

    public void setDispatchOrgName(String dispatchOrgName) {
        this.dispatchOrgName = dispatchOrgName;
    }
    public String getInsuranceInformation() {
        return insuranceInformation;
    }

    public void setInsuranceInformation(String insuranceInformation) {
        this.insuranceInformation = insuranceInformation;
    }
    public Long getManageId() {
        return manageId;
    }

    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getManageName() {
        return manageName;
    }

    public void setManageName(String manageName) {
        this.manageName = manageName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getManagePhone() {
        return managePhone;
    }

    public void setManagePhone(Long managePhone) {
        this.managePhone = managePhone;
    }
    public Long getApplyManageId() {
        return applyManageId;
    }

    public void setApplyManageId(Long applyManageId) {
        this.applyManageId = applyManageId;
    }
    public String getApplyManageName() {
        return applyManageName;
    }

    public void setApplyManageName(String applyManageName) {
        this.applyManageName = applyManageName;
    }
    public Long getUseId() {
        return useId;
    }

    public void setUseId(Long useId) {
        this.useId = useId;
    }
    public String getUseName() {
        return useName;
    }

    public void setUseName(String useName) {
        this.useName = useName;
    }
    public String getUsePhone() {
        return usePhone;
    }

    public void setUsePhone(String usePhone) {
        this.usePhone = usePhone;
    }
    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getApplyName() {
        return applyName;
    }

    public void setApplyName(String applyName) {
        this.applyName = applyName;
    }
    public Long getApplyDeptId() {
        return applyDeptId;
    }

    public void setApplyDeptId(Long applyDeptId) {
        this.applyDeptId = applyDeptId;
    }
    public String getApplyDeptName() {
        return applyDeptName;
    }

    public void setApplyDeptName(String applyDeptName) {
        this.applyDeptName = applyDeptName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-car-api-3.0.0-20251031.075733-71-sources.jar: com/ejianc/business/car/vo/DispatchVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 车辆调度
 * 
 * @author generator
 * 
 */
public class DispatchVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long carId; // 车牌号id
    private String carName; // 车辆名称 设备名称
    private String carCode; // 车牌号
    private Long carTypeId; // 车辆类型
    private String carTypeName; // 车辆类型
    private Long carAreaId; // 车辆所在区域
    private String carAreaName; // 车辆所在区域
    private Integer dispatchType; // 调度类型 0:临时调度；1:长期调度
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date beginDate; // 开始日期
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date endDate; // 归还日期
    private Long carProjectId; // 所属项目 车辆所在项目
    private String carProjectName; // 所属项目 车辆所在项目
    private Long orgId; // 所属组织
    private String orgName; // 所属组织
    private Long carOrgId; // 所属公司 车辆所属公司
    private String carOrgName; // 所属公司 车辆所属公司
    private Long dispatchProjectId; // 调入项目
    private String dispatchProjectName; // 调入项目
    private Long dispatchOrgId; // 调入公司
    private String dispatchOrgName; // 调入公司
    private String insuranceInformation; // 保险信息
    private Long manageId; // 主管
    private String manageName; // 主管
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private Long managePhone; // 主管手机号
    private Long applyManageId; // 申请主管
    private String applyManageName; // 申请主管
    private Long useId; // 使用人
    private String useName; // 使用人
    private String usePhone; // 使用人手机号
    private Long applyId; // 申请人
    private String applyName; // 申请人
    private Long applyDeptId; // 申请部门
    private String applyDeptName; // 申请部门
    private String memo; // 调车事由
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    private String billStateName;
    private String dispatchTypeName;

    public String getDispatchTypeName() {
        return dispatchTypeName;
    }

    public void setDispatchTypeName(String dispatchTypeName) {
        this.dispatchTypeName = dispatchTypeName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    @ReferSerialTransfer(referCode = "car-info")
    public Long getCarId() {
        return carId;
    }
    @ReferDeserialTransfer
    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getCarName() {
        return carName;
    }

    public void setCarName(String carName) {
        this.carName = carName;
    }
    public String getCarCode() {
        return carCode;
    }

    public void setCarCode(String carCode) {
        this.carCode = carCode;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getCarTypeId() {
        return carTypeId;
    }
    @ReferDeserialTransfer
    public void setCarTypeId(Long carTypeId) {
        this.carTypeId = carTypeId;
    }
    public String getCarTypeName() {
        return carTypeName;
    }

    public void setCarTypeName(String carTypeName) {
        this.carTypeName = carTypeName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getCarAreaId() {
        return carAreaId;
    }

    @ReferDeserialTransfer
    public void setCarAreaId(Long carAreaId) {
        this.carAreaId = carAreaId;
    }

    public String getCarAreaName() {
        return carAreaName;
    }

    public void setCarAreaName(String carAreaName) {
        this.carAreaName = carAreaName;
    }
    public Integer getDispatchType() {
        return dispatchType;
    }

    public void setDispatchType(Integer dispatchType) {
        this.dispatchType = dispatchType;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    @ReferSerialTransfer(referCode = "market-project")
    public Long getCarProjectId() {
        return carProjectId;
    }

    @ReferDeserialTransfer
    public void setCarProjectId(Long carProjectId) {
        this.carProjectId = carProjectId;
    }
    public String getCarProjectName() {
        return carProjectName;
    }

    public void setCarProjectName(String carProjectName) {
        this.carProjectName = carProjectName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getCarOrgId() {
        return carOrgId;
    }
    @ReferDeserialTransfer
    public void setCarOrgId(Long carOrgId) {
        this.carOrgId = carOrgId;
    }
    public String getCarOrgName() {
        return carOrgName;
    }

    public void setCarOrgName(String carOrgName) {
        this.carOrgName = carOrgName;
    }
    @ReferSerialTransfer(referCode = "market-project")
    public Long getDispatchProjectId() {
        return dispatchProjectId;
    }
    @ReferDeserialTransfer
    public void setDispatchProjectId(Long dispatchProjectId) {
        this.dispatchProjectId = dispatchProjectId;
    }
    public String getDispatchProjectName() {
        return dispatchProjectName;
    }

    public void setDispatchProjectName(String dispatchProjectName) {
        this.dispatchProjectName = dispatchProjectName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getDispatchOrgId() {
        return dispatchOrgId;
    }
    @ReferDeserialTransfer
    public void setDispatchOrgId(Long dispatchOrgId) {
        this.dispatchOrgId = dispatchOrgId;
    }
    public String getDispatchOrgName() {
        return dispatchOrgName;
    }

    public void setDispatchOrgName(String dispatchOrgName) {
        this.dispatchOrgName = dispatchOrgName;
    }
    public String getInsuranceInformation() {
        return insuranceInformation;
    }

    public void setInsuranceInformation(String insuranceInformation) {
        this.insuranceInformation = insuranceInformation;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getManageId() {
        return manageId;
    }
    @ReferDeserialTransfer
    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getManageName() {
        return manageName;
    }

    public void setManageName(String manageName) {
        this.manageName = manageName;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getManagePhone() {
        return managePhone;
    }

    public void setManagePhone(Long managePhone) {
        this.managePhone = managePhone;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getApplyManageId() {
        return applyManageId;
    }
    @ReferDeserialTransfer
    public void setApplyManageId(Long applyManageId) {
        this.applyManageId = applyManageId;
    }
    public String getApplyManageName() {
        return applyManageName;
    }

    public void setApplyManageName(String applyManageName) {
        this.applyManageName = applyManageName;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getUseId() {
        return useId;
    }
    @ReferDeserialTransfer
    public void setUseId(Long useId) {
        this.useId = useId;
    }
    public String getUseName() {
        return useName;
    }

    public void setUseName(String useName) {
        this.useName = useName;
    }
    public String getUsePhone() {
        return usePhone;
    }

    public void setUsePhone(String usePhone) {
        this.usePhone = usePhone;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getApplyId() {
        return applyId;
    }
    @ReferDeserialTransfer
    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getApplyName() {
        return applyName;
    }
    public void setApplyName(String applyName) {
        this.applyName = applyName;
    }
    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getApplyDeptId() {
        return applyDeptId;
    }
    @ReferDeserialTransfer
    public void setApplyDeptId(Long applyDeptId) {
        this.applyDeptId = applyDeptId;
    }
    public String getApplyDeptName() {
        return applyDeptName;
    }

    public void setApplyDeptName(String applyDeptName) {
        this.applyDeptName = applyDeptName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
